"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const getFileName_1 = require("./getFileName");
const getImports_1 = require("./getImports");
/**
 * Generate the OpenAPI client index file using the Handlebar template and write it to disk.
 * The index file just contains all the exports you need to use the client as a standalone
 * library. But yuo can also import individual models and services directly.
 * @param client Client object, containing, models, schemas and services.
 * @param language The output language (Typescript or javascript).
 * @param templates The loaded handlebar templates.
 * @param outputPathModels
 * @param outputPathServices
 * @param outputPath
 */
function writeClientIndex(client, language, templates, outputPathModels, outputPathServices, outputPath) {
    const fileName = getFileName_1.getFileName('index', language);
    try {
        fs.writeFileSync(path.resolve(outputPath, fileName), templates.index({
            server: client.server,
            version: client.version,
            models: getImports_1.getImports(outputPathModels),
            services: getImports_1.getImports(outputPathServices),
        }));
    }
    catch (e) {
        throw new Error(`Could not write index: "${fileName}"`);
    }
}
exports.writeClientIndex = writeClientIndex;
